@@ -42,6 +42,7 @@ enum wined3d_gl_extension
     APPLE_FLUSH_BUFFER_RANGE,
     APPLE_YCBCR_422,
     /* ARB */
+    ARB_BASE_INSTANCE,
     ARB_BLEND_FUNC_EXTENDED,
     ARB_CLEAR_BUFFER_OBJECT,
     ARB_CLEAR_TEXTURE,
@@ -56,6 +57,7 @@ enum wined3d_gl_extension
     ARB_DERIVATIVE_CONTROL,
     ARB_DRAW_BUFFERS,
     ARB_DRAW_ELEMENTS_BASE_VERTEX,
+    ARB_DRAW_INDIRECT,
     ARB_DRAW_INSTANCED,
     ARB_ES2_COMPATIBILITY,
     ARB_ES3_COMPATIBILITY,
